@@ -1,14 +1,9 @@
-try:
-    from collections import OrderedDict
-except ImportError:
-    # Support for Python 2.6
-    from ordereddict import OrderedDict
+from collections import OrderedDict
 
-from py.log import Producer
 from _pytest.runner import CollectReport
-
-from xdist.slavemanage import parse_spec_config
+from py.log import Producer
 from xdist.report import report_collection_diff
+from xdist.slavemanage import parse_spec_config
 
 
 class LoadScopeScheduling:
@@ -373,12 +368,12 @@ class LoadScopeScheduling:
         extra_nodes = len(self.nodes) - len(self.workqueue)
 
         if extra_nodes > 0:
-            self.log('Shuting down {} nodes'.format(extra_nodes))
+            self.log('Shuting down {0} nodes'.format(extra_nodes))
 
             for _ in range(extra_nodes):
                 unused_node, assigned = self.assigned_work.popitem(last=True)
 
-                self.log('Shuting down unused node {}'.format(unused_node))
+                self.log('Shuting down unused node {0}'.format(unused_node))
                 unused_node.shutdown()
 
         # Assign initial workload
